#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wherefrom-compat
version:              0.1.1.1
visibility:           public
id:                   wherefrom-compat-0.1.1.1-FCc9cyPQVNV96EwgVKRqnI
key:                  wherefrom-compat-0.1.1.1-FCc9cyPQVNV96EwgVKRqnI
license:              BSD-2-Clause
copyright:            The wherefrom-compat contributors
maintainer:           teofilcamarasu@gmail.com
author:               Teo Camarasu
synopsis:             A compatibility layer for GHC'\''s '\''wherefrom'\'' function
description:
    A compatibility layer for GHC'\''s '\''wherefrom'\'' function,
    which exposes info provenance information.
    Each major version of this library exports 
    a different version of this interface.

category:             Compatibility
abi:                  47a0fbd3de886188bb7184d804795722
exposed:              True
exposed-modules:      GHC.InfoProv.Compat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wherefrom-compat-0.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wherefrom-compat-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wherefrom-compat-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wherefrom-compat
hs-libraries:         HSwherefrom-compat-0.1.1.1-FCc9cyPQVNV96EwgVKRqnI
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-wherefrom-compat/html/wherefrom-compat.haddock

haddock-html:         /usr/share/doc/haskell-wherefrom-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

